%FIG3(PAR, MODEL, T) Creates figure 3 of the main manuscript
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function [] = fig3(par, model, T)

    Ip = model.par.Ip;
    
    %% Computation
    % model with no diffusion, no FB, no receptor dynamics
    par1 = setpar_scenario(par, Ip, 'rec_off');
    res1 = spacialwnt_simulation(T, par1, model);

    % model with no diffusion, no FB, but with receptor dynamics
    par2 = setpar_scenario(par, Ip, 'fb_off');
    res2 = spacialwnt_simulation(T, par2, model);

    % model with weak FB but no diffusion (10 times weaker than reference)
    par4 = setpar_scenario(par, Ip, 'diff_off');
    par3 = setpar(par4, 'c_mRNA', par4(Ip.c_mRNA)/10, Ip);
    res3 = spacialwnt_simulation(T, par3, model);

    % model with strong FB but no diffusion
    % par4 defined above
    res4 = spacialwnt_simulation(T, par4, model);

    % model with diffusion
    par5 = par;
    res5 = spacialwnt_simulation(T, par5, model);

    % model with very strong diffusion (50 times stronger than reference)
    par6 = setpar(par, 'D_diff', 50*par(Ip.D_diff), Ip);
    res6 = spacialwnt_simulation(T, par6, model);
    
    mRNA1 = res1.states.mRNA;
    mRNA2 = res2.states.mRNA;
    mRNA3 = res3.states.mRNA;
    mRNA4 = res4.states.mRNA;
    mRNA5 = res5.states.mRNA;
    mRNA6 = res6.states.mRNA;

    fact_readout_dkk = 100; %proportionality factor between readout mRNA and dkk mRNA

    ymax = 1.05 * max([max(mRNA1),max(mRNA2),max(mRNA3),max(mRNA4),max(mRNA5) max(mRNA6)])/fact_readout_dkk;

    %% Figure
    figure()

    subplot(5,3,1)
    bar(1:21,par(Ip.wnt),'b')
    xlim([0.5 21.5])
    ylim([0 5])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})
    title('Wnt')
    ylabel('A')
    
    subplot(5,3,2)
    bar(1:21,par(Ip.apc_tot),'b')
    xlim([0.5 21.5])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})
    title('APC')
    
    subplot(5,2,3)
    bar(1:21,mRNA1/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    ylim([0 ymax])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})
    title('signalling module')
    ylabel('B')

    subplot(5,2,4)
    bar(1:21,mRNA2/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})
    title('extended by receptor module')
    ylim([0 ymax])
    ylabel('C')

    subplot(5,2,5)
    bar(1:21,mRNA3/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    ylim([0 ymax])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})
    title('further extended by weak DKK feedback')
    ylabel('D')

    subplot(5,2,6)
    bar(1:21,mRNA4/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})
    ylim([0 ymax])
    title('alternative with strong DKK feedback')
    ylabel('E')

    subplot(5,2,7)
    bar(1:21,mRNA5/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    ylim([0 ymax])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})
    title('further extended by weak diffusion')
    ylabel('F')

    subplot(5,2,8)
    bar(1:21,mRNA6/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    ylim([0 ymax])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})
    title('alternative with strong diffusion')
    ylabel('G')
    
    subplot(5,3,13)
    FC(1) = mRNA1(1)/mRNA1(21);
    FC(2) = mRNA2(1)/mRNA2(21);
    FC(3) = mRNA3(1)/mRNA3(21);
    FC(4) = mRNA4(1)/mRNA4(21);
    FC(5) = mRNA5(1)/mRNA5(21);
    FC(6) = mRNA6(1)/mRNA6(21);

    barh(FC(6:-1:1),'r')
    set(gca,'YtickLabel',{'G','F','E','D','C','B'})
    ylabel('H')
    xlim([0 6])
    title('PC/PP ratio of target gene mRNA')

end

