%FIG4(PAR, MODEL, T) Creates figure 4 of the main manuscript
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function [] = fig4(par, model, T)

    Ip = model.par.Ip;
    
    %% Computation
    % constant Wnt, increasing APC (standard)
    par1 = par;
    res1 = spacialwnt_simulation(T, par1, model);
    mRNA1 = res1.states.mRNA;
    Wnt1 = par1(Ip.wnt);
    APC1 = par1(Ip.apc_tot); 
    
    %constant APC, increasing Wnt
    par2 = par;
    par2(Ip.wnt) = par2(Ip.apc_tot)/20;
    par2(Ip.apc_tot) = 100;    
    res2 = spacialwnt_simulation(T, par2, model);
    mRNA2 = res2.states.mRNA;
    Wnt2 = par2(Ip.wnt);
    APC2 = par2(Ip.apc_tot); 
    
    %increasing Wnt gradient yielding a decreasing TG expression profile
    par3 = par;
    par3(Ip.wnt) = par2(Ip.wnt);
    res3 = spacialwnt_simulation(T, par3, model);
    mRNA3 = res3.states.mRNA;
    Wnt3 = par3(Ip.wnt);
    APC3 = par3(Ip.apc_tot); 
    
    %increasing Wnt gradient yielding an increasing TG expression profile
    par4 = par;
    x_vec = linspace(0,1,model.ncell);
    par4(Ip.wnt) = 0.1*exp(log(50)*x_vec);   
    par4(Ip.apc_tot) = 50*exp(log(2)*x_vec); %in original submission: stated that 20-40 but actually 50-100
    res4 = spacialwnt_simulation(T, par4, model);
    mRNA4 = res4.states.mRNA;
    Wnt4 = par4(Ip.wnt);
    APC4 = par4(Ip.apc_tot); 
    
    %decreasing Wnt gradient
    par5 = par;
    par5(Ip.wnt) = par2(flip(Ip.wnt));
    res5 = spacialwnt_simulation(T, par5, model);
    mRNA5 = res5.states.mRNA;
    Wnt5 = par5(Ip.wnt);
    APC5 = par5(Ip.apc_tot); 
    
    %% figure y-axis
    fact_readout_dkk = 100; %proportionality factor between readout mRNA and dkk mRNA

    max_wnt = 1.05*max([max(Wnt1) max(Wnt2) max(Wnt3) max(Wnt4) max(Wnt5)]);
    max_apc = 1.05*max([max(APC1) max(APC2) max(APC3) max(APC4) max(APC5)]);
    max_mrna = 1.05*max([max(mRNA1) max(mRNA2) max(mRNA3) max(mRNA4) max(mRNA5)])/fact_readout_dkk;

    %% Figure
    % first row
    figure()
    subplot(5,3,1)
    bar(1:21,Wnt1,'b')
    xlim([0.5 21.5])
    ylim([0 max_wnt])
    title('Wnt')
    set(gca,'Xtick',[])
    ylabel('A')

    subplot(5,3,2)
    bar(1:21,APC1,'b')
    xlim([0.5 21.5])
    ylim([0 max_apc])
    title('APC')
    set(gca,'Xtick',[])

    subplot(5,3,3)
    bar(1:21,mRNA1/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    ylim([0 max_mrna])
    title('target gene mRNA')
    set(gca,'Xtick',[])

    %second row
    subplot(5,3,4)
    bar(1:21,Wnt2,'b')
    xlim([0.5 21.5])
    ylim([0 max_wnt])
    set(gca,'Xtick',[])
    ylabel('B')

    subplot(5,3,5)
    bar(1:21,APC2,'b')
    xlim([0.5 21.5])
    ylim([0 max_apc])
    set(gca,'Xtick',[])

    subplot(5,3,6)
    bar(1:21,mRNA2/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    ylim([0 max_mrna])
    set(gca,'Xtick',[])

    %third row

    subplot(5,3,7)
    bar(1:21,Wnt3,'b')
    xlim([0.5 21.5])
    ylim([0 max_wnt])
    set(gca,'Xtick',[])
    ylabel('C')

    subplot(5,3,8)
    bar(1:21,APC3,'b')
    xlim([0.5 21.5])
    ylim([0 max_apc])
    set(gca,'Xtick',[])

    subplot(5,3,9)
    bar(1:21,mRNA3/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    ylim([0 max_mrna])
    set(gca,'Xtick',[])

    %fourth row
    subplot(5,3,10)
    bar(1:21,Wnt4,'b')
    xlim([0.5 21.5])
    ylim([0 max_wnt])
    set(gca,'Xtick',[])
    ylabel('D')

    subplot(5,3,11)
    bar(1:21,APC4,'b')
    xlim([0.5 21.5])
    ylim([0 max_apc])
    set(gca,'Xtick',[])

    subplot(5,3,12)
    bar(1:21,mRNA4/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    ylim([0 max_mrna])
    set(gca,'Xtick',[])

    %fifth row
    subplot(5,3,13)
    bar(1:21,Wnt5,'b')
    xlim([0.5 21.5])
    ylim([0 max_wnt])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})
    ylabel('E')

    subplot(5,3,14)
    bar(1:21,APC5,'b')
    xlim([0.5 21.5])
    ylim([0 max_apc])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})

    subplot(5,3,15)
    bar(1:21,mRNA5/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    ylim([0 max_mrna])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})

    %% end of file
end

