%MODEL = SPACIALWNT_INDEX(NCELL) Creates indexing structure for spacial Wnt model
%   NCELL: number of cells in the spacial model
%
%   MODEL: a struct with the following fields:
%    .states, a struct with state information including indexing in
%       .Ix
%    .par
%       .Ip, a struct with parameter indexing
%       .npar, the total number of parameters
%    .ncell, the input NCELL
%    .mutcells, a logical vector of length NCELL specifying which cells,
%       if any, are mutants.
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function model = spacialwnt_index(ncell)

%% state variable indexing
Ix = struct;
Ix.bcat = 1;
Ix.apc = 2;
Ix.tcf = 3;
Ix.bcattcf = 4;
Ix.dsh_a = 5;
Ix.mRNA = 6;
Ix.dkk = 7;
Ix.dkklrp = 8;
Ix.wntfrz = 9;
Ix.wntcomp = 10;

%% parameter indexing

Ip = struct('npar',0);

% kinetic parameters
Ip = append(Ip, {'c1','k2','k3','K','k4','km4','k5','km5','c6','k7',...
                 'k8','k9','k10','k11'});

% receptor parameters
Ip = append(Ip, {'ki','kmi','ka','kma','ke','kme'});

% Dkk translation and diffusion parameters
Ip = append(Ip, {'D_diff','cl','c_mRNA','fact_cmRNA'});

% constant species/conserved quantities
Ip = append(Ip, {'lrp','frz','dsh_tot'});
Ip = append(Ip, {'wnt','apc_tot'}, ncell);


%% setting up a model struct with indexing variables and spacial info
model = struct;
model.states.Ix = Ix;
model.states.allstates = fieldnames(Ix);
model.states.nstate = length(fieldnames(Ix));
model.par.Ip = rmfield(Ip,'npar');
model.par.npar = Ip.npar;
model.ncell = ncell;
model.dx = 1/(ncell-1);

model.mutcells = false(1,ncell); % default scenario: no mutant cell

end

function Iout = append(Iin,name,nidx) 

    assert(isstruct(Iin), 'Input is not a struct')
    assert(~all(ismember(name,fieldnames(Iin))), 'Parameter name already in use')    
    if nargin < 3
        nidx = 1;
    end
    
    if iscell(name) %append several parameters with same length
        Iout = Iin;
        for i=1:length(name)
            n = Iout.npar;
            Iout.npar = n + nidx;
            Iout.(name{i}) = n + (1:nidx);
        end
    else %append only a single parameter
        Iout = Iin;
        n = Iin.npar;
        Iout.npar = n + nidx;
        Iout.(name) = n + (1:nidx);
    end
end
