%SPACIALWNT_ODE(t,X,par,model) Compute the RHS of the ODE system
%   Reaction-diffusion system discretised into ODE system; here, for
%   easier coding, state vector is reshaped into a matrix, with columns
%   corresponding to spacial positions and rows corresponding to species.
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function dX = spacialwnt_ode(~,X,par,model)

Ix = model.states.Ix;
Ip = model.par.Ip;

% notation simplified by working on a matrix structure
nstate = model.states.nstate;
ncell = model.ncell;
Xmat = reshape(X,nstate,ncell);
dX = zeros(size(Xmat));

% intracellular signal transduction
dX(Ix.bcat,:) = par(Ip.c1) - par(Ip.k2) * Xmat(Ix.bcat,:) ...
    - par(Ip.k3)*Xmat(Ix.apc,:).*Xmat(Ix.bcat,:)./(par(Ip.K) + Xmat(Ix.dsh_a,:)) ...
    - par(Ip.k4)*Xmat(Ix.apc,:).*Xmat(Ix.bcat,:) ...
    + par(Ip.km4)*(par(Ip.apc_tot) - Xmat(Ix.apc,:)) ...
    - par(Ip.k5)*Xmat(Ix.tcf,:).*Xmat(Ix.bcat,:) ...
    + par(Ip.km5)*Xmat(Ix.bcattcf,:);

dX(Ix.apc,:) = -par(Ip.k4)*Xmat(Ix.apc,:).*Xmat(Ix.bcat,:) ...
    + par(Ip.km4)*(par(Ip.apc_tot) ...
    - Xmat(Ix.apc,:));

dX(Ix.tcf,:) = -par(Ip.k5)*Xmat(Ix.tcf,:).*Xmat(Ix.bcat,:) ...
    + par(Ip.km5)*Xmat(Ix.bcattcf,:) ...
    + par(Ip.c6) ...
    - par(Ip.k7)*Xmat(Ix.tcf,:); 

dX(Ix.bcattcf,:) = par(Ip.k5)*Xmat(Ix.tcf,:).*Xmat(Ix.bcat,:) ...
    - par(Ip.km5)*Xmat(Ix.bcattcf,:);

dX(Ix.dsh_a,:) = par(Ip.k8)*(par(Ip.dsh_tot) - Xmat(Ix.dsh_a,:)).*Xmat(Ix.wntcomp,:) ...
    - par(Ip.k9)*Xmat(Ix.dsh_a,:);

dX(Ix.mRNA,:) = par(Ip.k10)*Xmat(Ix.bcattcf,:) ...
    - par(Ip.k11)*Xmat(Ix.mRNA,:);

% receptor dynamics

free_lrp = par(Ip.lrp) - Xmat(Ix.dkklrp,:) - Xmat(Ix.wntcomp,:);
free_wnt = par(Ip.wnt) - Xmat(Ix.wntfrz,:) - Xmat(Ix.wntcomp,:);
free_frz = par(Ip.frz) - Xmat(Ix.wntfrz,:) - Xmat(Ix.wntcomp,:);

dX(Ix.dkklrp,:) = par(Ip.ki)*Xmat(Ix.dkk,:).*free_lrp ...
    - par(Ip.kmi)*Xmat(Ix.dkklrp,:);
dX(Ix.wntfrz,:) = par(Ip.ka)*free_wnt.*free_frz ...
    - par(Ip.kmi)*Xmat(Ix.wntfrz,:) ...
    + par(Ip.kme)*Xmat(Ix.wntcomp,:) ...
    - par(Ip.ke)*free_lrp.*Xmat(Ix.wntfrz,:);
dX(Ix.wntcomp,:) = par(Ip.ke)*free_lrp.*Xmat(Ix.wntfrz,:) ...
    - par(Ip.kme)*Xmat(Ix.wntcomp,:);

%semidiscrete diffusion equation

i_ = 1:ncell;
i_dn = [1 1:(ncell-1)];
i_up = [2:ncell ncell];

dx = model.dx;

%Mutants may have different translation rate than WT
ratioVhep2Vdisse = 50; % ratio of intra- to extracellular volumes
transRate = repmat(par(Ip.c_mRNA)*ratioVhep2Vdisse, 1, ncell);
transRate(model.mutcells) = par(Ip.fact_cmRNA)*transRate(model.mutcells);  

dX(Ix.dkk,i_) = (par(Ip.D_diff)/dx^2) ...
    *(Xmat(Ix.dkk,i_dn) - 2*Xmat(Ix.dkk,i_) + Xmat(Ix.dkk,i_up))...
    + transRate.*Xmat(Ix.mRNA,i_)...
    - par(Ip.cl)*Xmat(Ix.dkk,i_)...
    + par(Ip.kmi)*Xmat(Ix.dkklrp,i_)...
    - par(Ip.ki)*Xmat(Ix.dkk,i_).*free_lrp;

% reshape matrix to vector
dX = dX(:);

end

