%SPACIALWNT_PARAMETERS Parameters of spacial Wnt model with Dkk diffusion
%   References for the parameter values can be found in Additional file 1.
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function par = spacialwnt_parameters(model)

Ip = model.par.Ip;

ncell = model.ncell;  % number of Hepatocytes along sinusoid
par = zeros(1,model.par.npar);

% kinetic parameters
par(Ip.c1) = 0.423;   % beta-catenin production
par(Ip.k2) = 2.57e-4; % APC-independent beta-catenin degradation
par(Ip.k3) = 3.08e-3; % APC-dependent beta-catenin degradation
par(Ip.K) = 18;       % baseline for Dsh-mediated inhibition of APC-dependent beta-catenin degradation
par(Ip.k4) = 1e5;     % degradation-independent binding of APC and beta-catenin
par(Ip.km4) = 1.2e8;  % degradation-independent dissociation of APC and beta-catenin
par(Ip.k5) = 3.33e-2; % binding of TCF and beta-catenin
par(Ip.km5) = 1;      % dissociation of TCF and beta-catenin
par(Ip.c6) = 0.686;   % TCF production
par(Ip.k7) = 8.4e-2;  % TCF degradation
par(Ip.k8) = 8e-3;    % Dsh activation by Wnt receptor complex
par(Ip.k9) = 6.7e-4;  % Dsh inactivation
par(Ip.dsh_tot) = 100;% total Dsh

par(Ip.k10) = 3e-3;   % Dkk translation
par(Ip.k11) = 1e-2;   % degradation of Dkk mRNA

% Dkk diffusion and gene expression
par(Ip.D_diff) = 1/150; % reference diffusion coefficient: 10 (\mu m)^2/sec = 1/150(x^2/min)
par(Ip.cl) = 0.1;       % extracellular Dkk clearance
par(Ip.c_mRNA) = 1/50;  % mRNA to Dkk translation rate
par(Ip.fact_cmRNA) = 1; % mRNA translation in mutant is multiplied by a factor

% Receptor dynamics
par(Ip.frz) = 5;       % Frizzled receptor density
par(Ip.lrp) = 30;      % LRP receptor density
par(Ip.ki) = 0.0618;   % Dkk / LRP binding
par(Ip.kmi) = 0.0303;  % Dkk / LRP dissociation
par(Ip.ka) = 0.0047;   % Wnt / Frz binding
par(Ip.kma) = 0.0282;  % Wnt / Frz dissociation
par(Ip.ke) = 1.68;     % WntFrz / LRP binding
par(Ip.kme) = 6;       % WntFrz / LRP dissociation

%% parameters / species varying between cells (gradients)
x_vec = linspace(0,1,ncell);
par(Ip.wnt) = 1*ones(size(x_vec));       % total Wnt
par(Ip.apc_tot) = 20*exp(log(5)*x_vec);  % total APC

end

