%RES = SPACIALWNT_SIMULATION(T, PAR, MODEL, OPTIONS) Simulate the Wnt model
%   T: final simulation time (for steady-state analysis)
%   PAR: parameter vector
%   MODEL: model struct as returned by 'spacialwnt_index'
%   OPTIONS: optional arguments (default values in {}):
%       .jactype: ['none' {'pattern'}] 
%   
%   RES: a struct with the following fields:
%    .states, a struct whose fields are the state names
%    .info, a struct containing the input options
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function res = spacialwnt_simulation(T, par, model, options)
    assert(isscalar(T) && isvector(par) && isstruct(model))
    
    if nargin < 4
        options = struct('jactype','pattern');
        % to be added later
    end
    
    ode_handle = @(t,X) spacialwnt_ode(t, X, par, model);
    X0 = spacialwnt_x0(par, model);
    
    % add options for ode (e.g. sparsity pattern)
    if isfield(options,'jactype') && strcmp(options.jactype, 'pattern')
        odeopt = struct('JPattern',sparsity(model),'MaxStep',Inf);
        [~, XOUT] = ode23s(ode_handle, [0 T], X0, odeopt);
    else
        [~, XOUT] = ode23s(ode_handle, [0 T], X0);
    end
    
    XT = XOUT(end,:); %only interested in steady-state
    XT = reshape(XT, model.states.nstate, model.ncell);
    
    Ix = model.states.Ix;
    
    states = struct;
    states.bcat = XT(Ix.bcat,:);
    states.apc = XT(Ix.apc,:);
    states.tcf = XT(Ix.tcf,:);
    states.bcattcf = XT(Ix.bcattcf,:);
    states.dhs_a = XT(Ix.dsh_a,:);
    states.mRNA = XT(Ix.mRNA,:);
    states.dkk = XT(Ix.dkk,:);
    states.dkklrp = XT(Ix.dkklrp,:);
    states.wntfrz = XT(Ix.wntfrz,:);
    states.wntcomp = XT(Ix.wntcomp,:);

    res = struct;
    res.states = states;
    res.info = struct('options',options);
    %to be completed if necessary
end

