%SPPATTERN = SPARSITY(MODEL) sparsity pattern of space discretised model
%   A sparse matrix representation of the nonzero jacobian entries is
%   returned based on the model structure of the space discretised
%   reaction-diffusion system.
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function sppattern = sparsity(model)

    n = model.ncell;
    I = model.states.Ix;
    
    % within-cell interactions among species
    % (does term in second column appear in ODE of first column?)
    blockindex = [
        I.bcat I.bcat;
        I.bcat I.apc;
        I.bcat I.tcf;
        I.bcat I.bcattcf;
        I.bcat I.dsh_a;
        I.apc  I.bcat;
        I.apc  I.apc;
        I.tcf  I.bcat;
        I.tcf  I.tcf;
        I.tcf  I.bcattcf;
        I.bcattcf I.bcat;
        I.bcattcf I.tcf;
        I.bcattcf I.bcattcf;
        I.dsh_a   I.dsh_a;
        I.dsh_a   I.dkk;
        I.dsh_a   I.wntcomp;
        I.mRNA  I.bcattcf;
        I.mRNA  I.mRNA;
        I.dkk   I.mRNA;
        I.dkk   I.dkk;
        I.dkk   I.dkklrp;
        I.dkk   I.wntcomp;
        I.dkklrp I.dkk;
        I.dkklrp I.dkklrp
        I.dkklrp I.wntcomp;
        I.wntfrz I.dkklrp;
        I.wntfrz I.wntfrz;
        I.wntfrz I.wntcomp;
        I.wntcomp I.dkklrp;
        I.wntcomp I.wntfrz;
        I.wntcomp I.wntcomp];

    blockindex_row = blockindex(:,1)';
    blockindex_col = blockindex(:,2)';
    blocklength = length(blockindex_row);

    % define between-cell interactions through Dkk
    diffindex_row = 10*reshape(repmat(1:n,2,1),1,2*n) - 10 + I.dkk;
    diffindex_col = 10*reshape([0:(n-1);2:(n+1)],1,2*n)-10 + I.dkk;
    
    difflength = length(diffindex_row);
    
    % assemble sparsity matrix
    totalindex_row = zeros(1,n*blocklength+difflength-2);
    totalindex_col = zeros(1,n*blocklength+difflength-2);
    
    for i = 0:(n-1)
        totalindex_row(i*blocklength+(1:blocklength)) = blockindex_row+10*i;
        totalindex_col(i*blocklength+(1:blocklength)) = blockindex_col+10*i;
    end
    
    totalindex_row((n*blocklength+1):end) = diffindex_row(2:(end-1));
    totalindex_col((n*blocklength+1):end) = diffindex_col(2:(end-1));

    sppattern = sparse(totalindex_row,totalindex_col,ones(size(totalindex_row)),10*n,10*n);
   
end

